@@ -23,6 +23,10 @@
 
    Text Reference for Old English Verses: TextRefOEVerses
 
+   Beware ! TextRef* classes don't store the source string you may used to initialize
+            such an object. You have to store this source string apart.
+
+
    Unit testing: see tests/textrefoeverses.py
 
    ____________________________________________________________________________
